waveformtools.extrapolate — waveformtools 2022-05-03 documentation

# waveformtools.extrapolate

Methods for waveform extrapolation.

Functions

`r_to_ra_conversion`(coord_radius[, mass, spin]) | Convert the isotropic co-ordinate radius parameter r in the ETK simulations
`waveextract_to_inf_perturbative_one_order`(...) | Extract a numerical waveform to null infinity using perturbative techniques. This is :
`waveextract_to_inf_perturbative_two_order`(...) | Extract a numerical waveform to null infinity using perturbative techniques. This is :
`waveextract_to_inf_perturbative_twop5_order`(...) | Extract a numerical waveform to null infinity using perturbative techniques. This is :

waveformtools.extrapolate.r_to_ra_conversion(coord_radius, mass=1, spin=0)
  Convert the isotropic co-ordinate radius parameter r in the ETK simulations

    into the approximate areal radius.

  Parameters:
    coord_radius: float

      The coordinate radius in the Einstein toolkit

    mass: float, optional

      The sum of the quasi-local horizon (Christodolou) masses of the black holes. Defaults to 1.

    spin: float, optional

      The magnitude of the spin of the system, as approximated by a single Kerr black hole far away from the system. Defaults to 0.

  Returns:
    areal_radius: float

      The appriximate areal radius of the sphere.

  Notes

  Assumes that the system interoir to the sphere at co-ordinate radius r_coord is well approximated by a Kerr black hole.

  References

  Nakano et al., (2015), Phys. Rev. D 91, 104022, in-text below Eq.[30].

waveformtools.extrapolate.waveextract_to_inf_perturbative_one_order(u_ret, rPsi4_rlm, areal_radius=500, ell=2)
  Extract a numerical waveform to null infinity using perturbative techniques. This is :

    - accurate to second order in \(1/r\).

    - accurate to first order in Kerr mass and spin.

    - corrects for spheroidal harmonics

  Parameters:
    u_ret: 1d array

      The retarted time array at the location r = areal_radius.

    rPsi4_rlm: 1d array

      The extracted Weyl scalar \(r\Psi_{4\ell m}\) data array

    areal_radius: 1d array

      The areal radius of the extraction sphere.

    mass: float

      The total horizon mass of the system.

    ell: int

      The polar quantum number \(\ell\).

    emm: int

      The azimuthal quantum number \(m\).

  Returns:
    rPsi4_inflm: 1d array

      The waveform extracted to null infninity \(\mathcal{I}^+\)

  References

  This implements the definition in Nakano et al., (2015), Phys. Rev. D 91, 104022 Eq.[29].

waveformtools.extrapolate.waveextract_to_inf_perturbative_two_order(rPsi4_rlm, delta_t, areal_radius=500, mass=1, ell=2)
  Extract a numerical waveform to null infinity using perturbative techniques. This is :

    - accurate to second order in \(1/r\).

    - accurate to first order in Kerr mass and spin.

    - corrects for spheroidal harmonics

  Parameters:
    rPsi4_rlm: 1d array

      The extracted Weyl scalar \(r\Psi_{4\ell m}\) data array.

    delta_t: float

      The time stepping.

    areal_radius: 1d array

      The areal radius of the extraction sphere.

    mass: float

      The total horizon mass of the system.

    spin: float, optional

      The effective spin of the spacetime. Defaults to 0.

    ell: int

      The polar quantum number \(\ell\).

    emm: int

      The azimuthal quantum number \(m\).

  Returns:
    rPsi4_inflm: 1d array

      The waveform extracted to null infninity \(\mathcal{I}^+\)

  References

  This implements the definition in Nakano et al., (2015), Phys. Rev. D 91, 104022 Eq.[29].

waveformtools.extrapolate.waveextract_to_inf_perturbative_twop5_order(rPsi4_rlm, delta_t, areal_radius=500, mass=1, spin=0, ell=2, emm=2)
  Extract a numerical waveform to null infinity using perturbative techniques. This is :

    - accurate to second order in \(1/r\).

    - accurate to first order in Kerr mass and spin.

    - corrects for spheroidal harmonics

  Parameters:
    rPsi4_rlm: 1d array

      The extracted Weyl scalar \(r\Psi_{4\ell m}\) data array

    delta_t: float

      The time stepping.

    areal_radius: 1d array

      The areal radius of the extraction sphere.

    mass: float

      The total horizon mass of the system.

    spin: float, optional

      The effective spin of the spacetime. Defaults to 0.

    ell: int

      The polar quantum number \(\ell\).

    emm: int

      The azimuthal quantum number \(m\).

  Returns:
    rPsi4_inflm: 1d array

      The waveform extracted to null infninity \(\mathcal{I}^+\)

  References

  This implements the definition in Nakano et al., (2015), Phys. Rev. D 91, 104022 Eq.[29].